@@ -25,7 +25,7 @@ from qubell.api.private import exceptions
 from qubell.api.tools import retry
 
 __all__ = ['COBALT_SECURE_STORE_TYPE', 'WORKFLOW_SERVICE_TYPE', 'SHARED_INSTANCE_CATALOG_TYPE',
-           'STATIC_RESOURCE_POOL_TYPE', 'CLOUD_ACCOUNT_TYPE']
+           'STATIC_RESOURCE_POOL_TYPE', 'CLOUD_ACCOUNT_TYPE', 'AMAZON_CLOUD_TYPE']
 
 # ToDo: Move to Globals
 
@@ -34,11 +34,13 @@ WORKFLOW_SERVICE_TYPE = 'builtin:workflow_service'
 SHARED_INSTANCE_CATALOG_TYPE = 'builtin:shared_instances_catalog'
 STATIC_RESOURCE_POOL_TYPE = 'builtin:static_resource_pool'
 CLOUD_ACCOUNT_TYPE = 'builtin:cloud_account'
+AMAZON_CLOUD_TYPE = 'builtin:amazon_account'
 
 system_application_types = {COBALT_SECURE_STORE_TYPE: 'Secure Vault 2.0', WORKFLOW_SERVICE_TYPE: 'Workflow Service',
                             SHARED_INSTANCE_CATALOG_TYPE: 'Shared Instances Catalog',
                             STATIC_RESOURCE_POOL_TYPE: 'Resource Pool',
-                            CLOUD_ACCOUNT_TYPE: 'Cloud Account'}
+                            CLOUD_ACCOUNT_TYPE: 'Cloud Account',
+                            AMAZON_CLOUD_TYPE: 'Amazon Account'}
 
 system_application_parameters = {
     COBALT_SECURE_STORE_TYPE: None,
